==> estateplat-common-1.2.4-20210319.024944-675-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjJyqdkDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地经营权调查表
 */
@Table(name = "DJSJ_JYQDK_DCB")
public class DjsjJyqdkDcb {
    @Id
    private String jyqdkdcb_index;
    private Date jykssj;
    private Date jyjssj;
    private String jyyt;
    private String dkszd;
    private String dkszn;
    private String dkszx;
    private String dkszb;
    private Double jymj;
    private Double scmj;
    private String tdyt;
    private String qlxz;
    private String bdcdyh;
    private String htbh;
    private String qlrmc;
    private String zl;

    public String getJyqdkdcb_index() {
        return jyqdkdcb_index;
    }

    public void setJyqdkdcb_index(String jyqdkdcb_index) {
        this.jyqdkdcb_index = jyqdkdcb_index;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public String getDkszd() {
        return dkszd;
    }

    public void setDkszd(String dkszd) {
        this.dkszd = dkszd;
    }

    public String getDkszn() {
        return dkszn;
    }

    public void setDkszn(String dkszn) {
        this.dkszn = dkszn;
    }

    public String getDkszx() {
        return dkszx;
    }

    public void setDkszx(String dkszx) {
        this.dkszx = dkszx;
    }

    public String getDkszb() {
        return dkszb;
    }

    public void setDkszb(String dkszb) {
        this.dkszb = dkszb;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }
}

==> estateplat-common-1.2.4-20210326.015358-682-sources.jar: cn/gtmap/estateplat/model/server/core/DjsjJyqdkDcb.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;
/**
 * @author <a href="mailto:jiangganzhi@gtmap.cn">jiangganzhi</a>
 * @version V1.0, 2021/3/16
 * @description 土地经营权调查表
 */
@Table(name = "DJSJ_JYQDK_DCB")
public class DjsjJyqdkDcb {
    @Id
    private String jyqdkdcb_index;
    private Date jykssj;
    private Date jyjssj;
    private String jyyt;
    private String dkszd;
    private String dkszn;
    private String dkszx;
    private String dkszb;
    private Double jymj;
    private Double scmj;
    private String tdyt;
    private String qlxz;
    private String bdcdyh;
    private String htbh;
    private String qlrmc;
    private String zl;
    private Double htzmjm;

    public String getJyqdkdcb_index() {
        return jyqdkdcb_index;
    }

    public void setJyqdkdcb_index(String jyqdkdcb_index) {
        this.jyqdkdcb_index = jyqdkdcb_index;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public String getDkszd() {
        return dkszd;
    }

    public void setDkszd(String dkszd) {
        this.dkszd = dkszd;
    }

    public String getDkszn() {
        return dkszn;
    }

    public void setDkszn(String dkszn) {
        this.dkszn = dkszn;
    }

    public String getDkszx() {
        return dkszx;
    }

    public void setDkszx(String dkszx) {
        this.dkszx = dkszx;
    }

    public String getDkszb() {
        return dkszb;
    }

    public void setDkszb(String dkszb) {
        this.dkszb = dkszb;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public Double getHtzmjm() {
        return htzmjm;
    }

    public void setHtzmjm(Double htzmjm) {
        this.htzmjm = htzmjm;
    }
}
